@@ -3,6 +3,7 @@
 import socket
 import errno
 from kola.utils import safe_call
+from kola.vals import logger
 
 
 class GStream(object):
@@ -42,6 +43,16 @@ class GStream(object):
         """
         self.on_close_callback = callback
 
+    def read_util(self, terminator, on_read_complete):
+        """
+        为了兼容调用的方法
+        """
+        if terminator != '\n':
+            logger.error('only support \\n as terminator for now, terminator: %s', terminator)
+            raise TypeError('only support \\n as terminator for now')
+
+        self.readline(on_read_complete)
+
     def readline(self, on_read_complete):
         """
         接收消息
